# onboarding-buddy-client
This document details all the available operations in the Onboarding Buddy API specification

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.0
- Generator version: 7.12.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import onboarding_buddy_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import onboarding_buddy_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import onboarding_buddy_client
from onboarding_buddy_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.onboardingbuddy.co
# See configuration.py for a list of all supported configuration parameters.
configuration = onboarding_buddy_client.Configuration(
    host = "https://api.onboardingbuddy.co"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKey
configuration.api_key['ApiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKey'] = 'Bearer'

# Configure API key authorization: AppKey
configuration.api_key['AppKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['AppKey'] = 'Bearer'

# Configure API key authorization: ApiSecret
configuration.api_key['ApiSecret'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiSecret'] = 'Bearer'


# Enter a context with an instance of the API client
with onboarding_buddy_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = onboarding_buddy_client.BatchApi(api_client)
    batch_id = 'batch_id_example' # str | 

    try:
        # Get the results for a batch - browser
        api_response = api_instance.get_browser_batch(batch_id)
        print("The response of BatchApi->get_browser_batch:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling BatchApi->get_browser_batch: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.onboardingbuddy.co*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BatchApi* | [**get_browser_batch**](docs/BatchApi.md#get_browser_batch) | **GET** /validation-service/batch/browser/{batchId} | Get the results for a batch - browser
*BatchApi* | [**get_emailaddress_batch**](docs/BatchApi.md#get_emailaddress_batch) | **GET** /validation-service/batch/email-address/{batchId} | Get the results for a batch - email address
*BatchApi* | [**get_ipaddress_batch**](docs/BatchApi.md#get_ipaddress_batch) | **GET** /validation-service/batch/ip-address/{batchId} | Get the results for a batch - ip address
*BatchApi* | [**get_mobilenumber_batch**](docs/BatchApi.md#get_mobilenumber_batch) | **GET** /validation-service/batch/mobile/{batchId} | Get the results for a batch - mobile number
*BatchApi* | [**poll_batch**](docs/BatchApi.md#poll_batch) | **GET** /validation-service/batch/poll/{batchId} | Poll the state of a batch submitted for processing
*BatchApi* | [**submit_browser_batch**](docs/BatchApi.md#submit_browser_batch) | **POST** /validation-service/batch/browser | Perform browser validation for a batch of values
*BatchApi* | [**submit_emailaddress_batch**](docs/BatchApi.md#submit_emailaddress_batch) | **POST** /validation-service/batch/email-address | Perform email address validation for a batch of values
*BatchApi* | [**submit_ipaddress_batch**](docs/BatchApi.md#submit_ipaddress_batch) | **POST** /validation-service/batch/ip-address | Perform ip address validation for a batch of values
*BatchApi* | [**submit_mobilenumber_batch**](docs/BatchApi.md#submit_mobilenumber_batch) | **POST** /validation-service/batch/mobile | Perform mobile number validation for a batch of values
*FileApi* | [**document_rag**](docs/FileApi.md#document_rag) | **POST** /file-service/query/rag | Document RAG
*FileApi* | [**download**](docs/FileApi.md#download) | **GET** /file-service/download/{fileGlobalId} | File Download
*FileApi* | [**get_file_record**](docs/FileApi.md#get_file_record) | **GET** /file-service/management/{fileGlobalId} | Get File
*FileApi* | [**get_file_records**](docs/FileApi.md#get_file_records) | **GET** /file-service/management | Get Files
*FileApi* | [**search_file_records**](docs/FileApi.md#search_file_records) | **POST** /file-service/search | Search Files
*FileApi* | [**upload**](docs/FileApi.md#upload) | **POST** /file-service/upload | File Upload
*SanctionsApi* | [**aircraft**](docs/SanctionsApi.md#aircraft) | **POST** /sanction-service/check/aircraft | Perform an aircraft sanctions check
*SanctionsApi* | [**crypto_wallet**](docs/SanctionsApi.md#crypto_wallet) | **POST** /sanction-service/check/crypto-wallet | Perform a crypto wallet sanctions check
*SanctionsApi* | [**entity**](docs/SanctionsApi.md#entity) | **POST** /sanction-service/check/entity | Perform an entity sanctions check
*SanctionsApi* | [**individual**](docs/SanctionsApi.md#individual) | **POST** /sanction-service/check/individual | Perform an individual sanctions list check
*SanctionsApi* | [**vessel**](docs/SanctionsApi.md#vessel) | **POST** /sanction-service/check/vessel | Perform a vessel sanctions check
*ValidationApi* | [**browser**](docs/ValidationApi.md#browser) | **POST** /validation-service/validation/browser | Perform a browser validation
*ValidationApi* | [**email**](docs/ValidationApi.md#email) | **POST** /validation-service/validation/email | Perform an email validation
*ValidationApi* | [**ipaddress**](docs/ValidationApi.md#ipaddress) | **POST** /validation-service/validation/ipaddress | Perform an ip address validation
*ValidationApi* | [**mobile**](docs/ValidationApi.md#mobile) | **POST** /validation-service/validation/mobile | Perform a mobile validation


## Documentation For Models

 - [AircraftSanctionRecordM](docs/AircraftSanctionRecordM.md)
 - [AircraftSanctionsCheckRequestM](docs/AircraftSanctionsCheckRequestM.md)
 - [AircraftSanctionsCheckResponseM](docs/AircraftSanctionsCheckResponseM.md)
 - [BrowserGetBatchResponseM](docs/BrowserGetBatchResponseM.md)
 - [BrowserRequestM](docs/BrowserRequestM.md)
 - [BrowserResponseM](docs/BrowserResponseM.md)
 - [BrowserResultM](docs/BrowserResultM.md)
 - [BrowserSubmitBatchRequestM](docs/BrowserSubmitBatchRequestM.md)
 - [CryptoWalletSanctionsCheckRequestM](docs/CryptoWalletSanctionsCheckRequestM.md)
 - [CryptoWalletSanctionsCheckResponseM](docs/CryptoWalletSanctionsCheckResponseM.md)
 - [DigitalCurrencyAddressM](docs/DigitalCurrencyAddressM.md)
 - [EmailAddressGetBatchResponseM](docs/EmailAddressGetBatchResponseM.md)
 - [EmailAddressRequestM](docs/EmailAddressRequestM.md)
 - [EmailAddressResponseM](docs/EmailAddressResponseM.md)
 - [EmailAddressResultM](docs/EmailAddressResultM.md)
 - [EmailAddressSubmitBatchRequestM](docs/EmailAddressSubmitBatchRequestM.md)
 - [EmailEntityRecordM](docs/EmailEntityRecordM.md)
 - [EmailIndividualRecordM](docs/EmailIndividualRecordM.md)
 - [EmailSanctionRecordM](docs/EmailSanctionRecordM.md)
 - [EntitySanctionsCheckRequestM](docs/EntitySanctionsCheckRequestM.md)
 - [EntitySanctionsCheckResponseM](docs/EntitySanctionsCheckResponseM.md)
 - [FileContainerM](docs/FileContainerM.md)
 - [FileRecordListResponseM](docs/FileRecordListResponseM.md)
 - [FileRecordM](docs/FileRecordM.md)
 - [FileRecordMetaDataM](docs/FileRecordMetaDataM.md)
 - [FileRecordResponseM](docs/FileRecordResponseM.md)
 - [FileUploadResponseM](docs/FileUploadResponseM.md)
 - [IndividualAddressM](docs/IndividualAddressM.md)
 - [IndividualAliasM](docs/IndividualAliasM.md)
 - [IndividualSanctionRecordM](docs/IndividualSanctionRecordM.md)
 - [IndividualSanctionsCheckRequestM](docs/IndividualSanctionsCheckRequestM.md)
 - [IndividualSanctionsCheckResponseM](docs/IndividualSanctionsCheckResponseM.md)
 - [IpAddressGetBatchResponseM](docs/IpAddressGetBatchResponseM.md)
 - [IpAddressRequestM](docs/IpAddressRequestM.md)
 - [IpAddressResponseM](docs/IpAddressResponseM.md)
 - [IpAddressResultM](docs/IpAddressResultM.md)
 - [IpAddressSubmitBatchRequestM](docs/IpAddressSubmitBatchRequestM.md)
 - [MobileNumberGetBatchResponseM](docs/MobileNumberGetBatchResponseM.md)
 - [MobileNumberM](docs/MobileNumberM.md)
 - [MobileNumberRequestM](docs/MobileNumberRequestM.md)
 - [MobileNumberResponseM](docs/MobileNumberResponseM.md)
 - [MobileNumberResultM](docs/MobileNumberResultM.md)
 - [MobileNumberSubmitBatchRequestM](docs/MobileNumberSubmitBatchRequestM.md)
 - [OtherSanctionRecordM](docs/OtherSanctionRecordM.md)
 - [PollBatchResponseM](docs/PollBatchResponseM.md)
 - [RagQueryRequestM](docs/RagQueryRequestM.md)
 - [RagQueryResponseM](docs/RagQueryResponseM.md)
 - [SearchFileRecordM](docs/SearchFileRecordM.md)
 - [SearchFileRequestM](docs/SearchFileRequestM.md)
 - [SearchFileResponseM](docs/SearchFileResponseM.md)
 - [SubmitBatchResponseM](docs/SubmitBatchResponseM.md)
 - [VesselSanctionsCheckRequestM](docs/VesselSanctionsCheckRequestM.md)
 - [VesselSanctionsCheckResponseM](docs/VesselSanctionsCheckResponseM.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="AppKey"></a>
### AppKey

- **Type**: API key
- **API key parameter name**: ob-app-key
- **Location**: HTTP header

<a id="ApiKey"></a>
### ApiKey

- **Type**: API key
- **API key parameter name**: ob-api-key
- **Location**: HTTP header

<a id="ApiSecret"></a>
### ApiSecret

- **Type**: API key
- **API key parameter name**: ob-api-secret
- **Location**: HTTP header


## Author




